import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
import { ComplexComputedList } from "cdktf";
/**
 *
 */
export interface ContainerConfig extends TerraformMetaArguments {
    /**
     *
     */
    readonly attach?: boolean;
    /**
     *
     */
    readonly command?: string[];
    /**
     *
     */
    readonly cpuSet?: string;
    /**
     *
     */
    readonly cpuShares?: number;
    /**
     *
     */
    readonly destroyGraceSeconds?: number;
    /**
     *
     */
    readonly dns?: string[];
    /**
     *
     */
    readonly dnsOpts?: string[];
    /**
     *
     */
    readonly dnsSearch?: string[];
    /**
     *
     */
    readonly domainname?: string;
    /**
     *
     */
    readonly entrypoint?: string[];
    /**
     *
     */
    readonly env?: string[];
    /**
     * Additional groups for the container user.
     */
    readonly groupAdd?: string[];
    /**
     *
     */
    readonly hostname?: string;
    /**
     *
     */
    readonly image: string;
    /**
     * IPC sharing mode for the container.
     */
    readonly ipcMode?: string;
    /**
     *
     */
    readonly links?: string[];
    /**
     *
     */
    readonly logDriver?: string;
    /**
     *
     */
    readonly logOpts?: {
        [key: string]: string;
    };
    /**
     *
     */
    readonly logs?: boolean;
    /**
     *
     */
    readonly maxRetryCount?: number;
    /**
     *
     */
    readonly memory?: number;
    /**
     *
     */
    readonly memorySwap?: number;
    /**
     *
     */
    readonly mustRun?: boolean;
    /**
     *
     */
    readonly name: string;
    /**
     * Set an alias for the container in all specified networks.
     */
    readonly networkAlias?: string[];
    /**
     *
     */
    readonly networkMode?: string;
    /**
     *
     */
    readonly networks?: string[];
    /**
     *
     */
    readonly pidMode?: string;
    /**
     *
     */
    readonly privileged?: boolean;
    /**
     *
     */
    readonly publishAllPorts?: boolean;
    /**
     *
     */
    readonly readOnly?: boolean;
    /**
     *
     */
    readonly restart?: string;
    /**
     *
     */
    readonly rm?: boolean;
    /**
     *
     */
    readonly shmSize?: number;
    /**
     *
     */
    readonly start?: boolean;
    /**
     *
     */
    readonly sysctls?: {
        [key: string]: string;
    };
    /**
     *
     */
    readonly tmpfs?: {
        [key: string]: string;
    };
    /**
     *
     */
    readonly user?: string;
    /**
     *
     */
    readonly usernsMode?: string;
    /**
     *
     */
    readonly workingDir?: string;
    /**
     * capabilities block.
     */
    readonly capabilities?: ContainerCapabilities[];
    /**
     * devices block.
     */
    readonly devices?: ContainerDevices[];
    /**
     * healthcheck block.
     */
    readonly healthcheck?: ContainerHealthcheck[];
    /**
     * host block.
     */
    readonly host?: ContainerHost[];
    /**
     * labels block.
     */
    readonly labels?: ContainerLabels[];
    /**
     * mounts block.
     */
    readonly mounts?: ContainerMounts[];
    /**
     * networks_advanced block.
     */
    readonly networksAdvanced?: ContainerNetworksAdvanced[];
    /**
     * ports block.
     */
    readonly ports?: ContainerPorts[];
    /**
     * ulimit block.
     */
    readonly ulimit?: ContainerUlimit[];
    /**
     * upload block.
     */
    readonly upload?: ContainerUpload[];
    /**
     * volumes block.
     */
    readonly volumes?: ContainerVolumes[];
}
/**
 *
 */
export declare class ContainerNetworkData extends ComplexComputedList {
    /**
     *
     */
    get gateway(): string;
    /**
     *
     */
    get ipAddress(): string;
    /**
     *
     */
    get ipPrefixLength(): number;
    /**
     *
     */
    get networkName(): string;
}
/**
 *
 */
export interface ContainerCapabilities {
    /**
     *
     */
    readonly add?: string[];
    /**
     *
     */
    readonly drop?: string[];
}
/**
 *
 */
export interface ContainerDevices {
    /**
     *
     */
    readonly containerPath?: string;
    /**
     *
     */
    readonly hostPath: string;
    /**
     *
     */
    readonly permissions?: string;
}
/**
 *
 */
export interface ContainerHealthcheck {
    /**
     * Time between running the check (ms|s|m|h).
     */
    readonly interval?: string;
    /**
     * Consecutive failures needed to report unhealthy.
     */
    readonly retries?: number;
    /**
     * Start period for the container to initialize before counting retries towards unstable (ms|s|m|h).
     */
    readonly startPeriod?: string;
    /**
     * The test to perform as list.
     */
    readonly test: string[];
    /**
     * Maximum time to allow one check to run (ms|s|m|h).
     */
    readonly timeout?: string;
}
/**
 *
 */
export interface ContainerHost {
    /**
     *
     */
    readonly host: string;
    /**
     *
     */
    readonly ip: string;
}
/**
 *
 */
export interface ContainerLabels {
    /**
     * Name of the label.
     */
    readonly label: string;
    /**
     * Value of the label.
     */
    readonly value: string;
}
/**
 *
 */
export interface ContainerMountsBindOptions {
    /**
     * A propagation mode with the value.
     */
    readonly propagation?: string;
}
/**
 *
 */
export interface ContainerMountsTmpfsOptions {
    /**
     * The permission mode for the tmpfs mount in an integer.
     */
    readonly mode?: number;
    /**
     * The size for the tmpfs mount in bytes.
     */
    readonly sizeBytes?: number;
}
/**
 *
 */
export interface ContainerMountsVolumeOptionsLabels {
    /**
     * Name of the label.
     */
    readonly label: string;
    /**
     * Value of the label.
     */
    readonly value: string;
}
/**
 *
 */
export interface ContainerMountsVolumeOptions {
    /**
     * Name of the driver to use to create the volume.
     */
    readonly driverName?: string;
    /**
     * key/value map of driver specific options.
     */
    readonly driverOptions?: {
        [key: string]: string;
    };
    /**
     * Populate volume with data from the target.
     */
    readonly noCopy?: boolean;
    /**
     * labels block.
     */
    readonly labels?: ContainerMountsVolumeOptionsLabels[];
}
/**
 *
 */
export interface ContainerMounts {
    /**
     * Whether the mount should be read-only.
     */
    readonly readOnly?: boolean;
    /**
     * Mount source (e.g. a volume name, a host path).
     */
    readonly source?: string;
    /**
     * Container path.
     */
    readonly target: string;
    /**
     * The mount type.
     */
    readonly type: string;
    /**
     * bind_options block.
     */
    readonly bindOptions?: ContainerMountsBindOptions[];
    /**
     * tmpfs_options block.
     */
    readonly tmpfsOptions?: ContainerMountsTmpfsOptions[];
    /**
     * volume_options block.
     */
    readonly volumeOptions?: ContainerMountsVolumeOptions[];
}
/**
 *
 */
export interface ContainerNetworksAdvanced {
    /**
     *
     */
    readonly aliases?: string[];
    /**
     *
     */
    readonly ipv4Address?: string;
    /**
     *
     */
    readonly ipv6Address?: string;
    /**
     *
     */
    readonly name: string;
}
/**
 *
 */
export interface ContainerPorts {
    /**
     *
     */
    readonly external?: number;
    /**
     *
     */
    readonly internal: number;
    /**
     *
     */
    readonly ip?: string;
    /**
     *
     */
    readonly protocol?: string;
}
/**
 *
 */
export interface ContainerUlimit {
    /**
     *
     */
    readonly hard: number;
    /**
     *
     */
    readonly name: string;
    /**
     *
     */
    readonly soft: number;
}
/**
 *
 */
export interface ContainerUpload {
    /**
     *
     */
    readonly content?: string;
    /**
     *
     */
    readonly contentBase64?: string;
    /**
     *
     */
    readonly executable?: boolean;
    /**
     *
     */
    readonly file: string;
    /**
     *
     */
    readonly source?: string;
    /**
     *
     */
    readonly sourceHash?: string;
}
/**
 *
 */
export interface ContainerVolumes {
    /**
     *
     */
    readonly containerPath?: string;
    /**
     *
     */
    readonly fromContainer?: string;
    /**
     *
     */
    readonly hostPath?: string;
    /**
     *
     */
    readonly readOnly?: boolean;
    /**
     *
     */
    readonly volumeName?: string;
}
/**
 *
 */
export declare class Container extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: ContainerConfig);
    private _attach?;
    /**
     *
     */
    get attach(): boolean;
    /**
     *
     */
    set attach(value: boolean);
    /**
     *
     */
    resetAttach(): void;
    /**
     *
     */
    get attachInput(): boolean | undefined;
    /**
     *
     */
    get bridge(): string;
    private _command?;
    /**
     *
     */
    get command(): string[];
    /**
     *
     */
    set command(value: string[]);
    /**
     *
     */
    resetCommand(): void;
    /**
     *
     */
    get commandInput(): string[] | undefined;
    /**
     *
     */
    get containerLogs(): string;
    private _cpuSet?;
    /**
     *
     */
    get cpuSet(): string;
    /**
     *
     */
    set cpuSet(value: string);
    /**
     *
     */
    resetCpuSet(): void;
    /**
     *
     */
    get cpuSetInput(): string | undefined;
    private _cpuShares?;
    /**
     *
     */
    get cpuShares(): number;
    /**
     *
     */
    set cpuShares(value: number);
    /**
     *
     */
    resetCpuShares(): void;
    /**
     *
     */
    get cpuSharesInput(): number | undefined;
    private _destroyGraceSeconds?;
    /**
     *
     */
    get destroyGraceSeconds(): number;
    /**
     *
     */
    set destroyGraceSeconds(value: number);
    /**
     *
     */
    resetDestroyGraceSeconds(): void;
    /**
     *
     */
    get destroyGraceSecondsInput(): number | undefined;
    private _dns?;
    /**
     *
     */
    get dns(): string[];
    /**
     *
     */
    set dns(value: string[]);
    /**
     *
     */
    resetDns(): void;
    /**
     *
     */
    get dnsInput(): string[] | undefined;
    private _dnsOpts?;
    /**
     *
     */
    get dnsOpts(): string[];
    /**
     *
     */
    set dnsOpts(value: string[]);
    /**
     *
     */
    resetDnsOpts(): void;
    /**
     *
     */
    get dnsOptsInput(): string[] | undefined;
    private _dnsSearch?;
    /**
     *
     */
    get dnsSearch(): string[];
    /**
     *
     */
    set dnsSearch(value: string[]);
    /**
     *
     */
    resetDnsSearch(): void;
    /**
     *
     */
    get dnsSearchInput(): string[] | undefined;
    private _domainname?;
    /**
     *
     */
    get domainname(): string;
    /**
     *
     */
    set domainname(value: string);
    /**
     *
     */
    resetDomainname(): void;
    /**
     *
     */
    get domainnameInput(): string | undefined;
    private _entrypoint?;
    /**
     *
     */
    get entrypoint(): string[];
    /**
     *
     */
    set entrypoint(value: string[]);
    /**
     *
     */
    resetEntrypoint(): void;
    /**
     *
     */
    get entrypointInput(): string[] | undefined;
    private _env?;
    /**
     *
     */
    get env(): string[];
    /**
     *
     */
    set env(value: string[]);
    /**
     *
     */
    resetEnv(): void;
    /**
     *
     */
    get envInput(): string[] | undefined;
    /**
     *
     */
    get exitCode(): number;
    /**
     *
     */
    get gateway(): string;
    private _groupAdd?;
    /**
     *
     */
    get groupAdd(): string[];
    /**
     *
     */
    set groupAdd(value: string[]);
    /**
     *
     */
    resetGroupAdd(): void;
    /**
     *
     */
    get groupAddInput(): string[] | undefined;
    private _hostname?;
    /**
     *
     */
    get hostname(): string;
    /**
     *
     */
    set hostname(value: string);
    /**
     *
     */
    resetHostname(): void;
    /**
     *
     */
    get hostnameInput(): string | undefined;
    /**
     *
     */
    get id(): string;
    private _image;
    /**
     *
     */
    get image(): string;
    /**
     *
     */
    set image(value: string);
    /**
     *
     */
    get imageInput(): string;
    /**
     *
     */
    get ipAddress(): string;
    /**
     *
     */
    get ipPrefixLength(): number;
    private _ipcMode?;
    /**
     *
     */
    get ipcMode(): string;
    /**
     *
     */
    set ipcMode(value: string);
    /**
     *
     */
    resetIpcMode(): void;
    /**
     *
     */
    get ipcModeInput(): string | undefined;
    private _links?;
    /**
     *
     */
    get links(): string[];
    /**
     *
     */
    set links(value: string[]);
    /**
     *
     */
    resetLinks(): void;
    /**
     *
     */
    get linksInput(): string[] | undefined;
    private _logDriver?;
    /**
     *
     */
    get logDriver(): string;
    /**
     *
     */
    set logDriver(value: string);
    /**
     *
     */
    resetLogDriver(): void;
    /**
     *
     */
    get logDriverInput(): string | undefined;
    private _logOpts?;
    /**
     *
     */
    get logOpts(): {
        [key: string]: string;
    };
    /**
     *
     */
    set logOpts(value: {
        [key: string]: string;
    });
    /**
     *
     */
    resetLogOpts(): void;
    /**
     *
     */
    get logOptsInput(): {
        [key: string]: string;
    } | undefined;
    private _logs?;
    /**
     *
     */
    get logs(): boolean;
    /**
     *
     */
    set logs(value: boolean);
    /**
     *
     */
    resetLogs(): void;
    /**
     *
     */
    get logsInput(): boolean | undefined;
    private _maxRetryCount?;
    /**
     *
     */
    get maxRetryCount(): number;
    /**
     *
     */
    set maxRetryCount(value: number);
    /**
     *
     */
    resetMaxRetryCount(): void;
    /**
     *
     */
    get maxRetryCountInput(): number | undefined;
    private _memory?;
    /**
     *
     */
    get memory(): number;
    /**
     *
     */
    set memory(value: number);
    /**
     *
     */
    resetMemory(): void;
    /**
     *
     */
    get memoryInput(): number | undefined;
    private _memorySwap?;
    /**
     *
     */
    get memorySwap(): number;
    /**
     *
     */
    set memorySwap(value: number);
    /**
     *
     */
    resetMemorySwap(): void;
    /**
     *
     */
    get memorySwapInput(): number | undefined;
    private _mustRun?;
    /**
     *
     */
    get mustRun(): boolean;
    /**
     *
     */
    set mustRun(value: boolean);
    /**
     *
     */
    resetMustRun(): void;
    /**
     *
     */
    get mustRunInput(): boolean | undefined;
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    /**
     *
     */
    get nameInput(): string;
    private _networkAlias?;
    /**
     *
     */
    get networkAlias(): string[];
    /**
     *
     */
    set networkAlias(value: string[]);
    /**
     *
     */
    resetNetworkAlias(): void;
    /**
     *
     */
    get networkAliasInput(): string[] | undefined;
    /**
     *
     */
    networkData(index: string): ContainerNetworkData;
    private _networkMode?;
    /**
     *
     */
    get networkMode(): string;
    /**
     *
     */
    set networkMode(value: string);
    /**
     *
     */
    resetNetworkMode(): void;
    /**
     *
     */
    get networkModeInput(): string | undefined;
    private _networks?;
    /**
     *
     */
    get networks(): string[];
    /**
     *
     */
    set networks(value: string[]);
    /**
     *
     */
    resetNetworks(): void;
    /**
     *
     */
    get networksInput(): string[] | undefined;
    private _pidMode?;
    /**
     *
     */
    get pidMode(): string;
    /**
     *
     */
    set pidMode(value: string);
    /**
     *
     */
    resetPidMode(): void;
    /**
     *
     */
    get pidModeInput(): string | undefined;
    private _privileged?;
    /**
     *
     */
    get privileged(): boolean;
    /**
     *
     */
    set privileged(value: boolean);
    /**
     *
     */
    resetPrivileged(): void;
    /**
     *
     */
    get privilegedInput(): boolean | undefined;
    private _publishAllPorts?;
    /**
     *
     */
    get publishAllPorts(): boolean;
    /**
     *
     */
    set publishAllPorts(value: boolean);
    /**
     *
     */
    resetPublishAllPorts(): void;
    /**
     *
     */
    get publishAllPortsInput(): boolean | undefined;
    private _readOnly?;
    /**
     *
     */
    get readOnly(): boolean;
    /**
     *
     */
    set readOnly(value: boolean);
    /**
     *
     */
    resetReadOnly(): void;
    /**
     *
     */
    get readOnlyInput(): boolean | undefined;
    private _restart?;
    /**
     *
     */
    get restart(): string;
    /**
     *
     */
    set restart(value: string);
    /**
     *
     */
    resetRestart(): void;
    /**
     *
     */
    get restartInput(): string | undefined;
    private _rm?;
    /**
     *
     */
    get rm(): boolean;
    /**
     *
     */
    set rm(value: boolean);
    /**
     *
     */
    resetRm(): void;
    /**
     *
     */
    get rmInput(): boolean | undefined;
    private _shmSize?;
    /**
     *
     */
    get shmSize(): number;
    /**
     *
     */
    set shmSize(value: number);
    /**
     *
     */
    resetShmSize(): void;
    /**
     *
     */
    get shmSizeInput(): number | undefined;
    private _start?;
    /**
     *
     */
    get start(): boolean;
    /**
     *
     */
    set start(value: boolean);
    /**
     *
     */
    resetStart(): void;
    /**
     *
     */
    get startInput(): boolean | undefined;
    private _sysctls?;
    /**
     *
     */
    get sysctls(): {
        [key: string]: string;
    };
    /**
     *
     */
    set sysctls(value: {
        [key: string]: string;
    });
    /**
     *
     */
    resetSysctls(): void;
    /**
     *
     */
    get sysctlsInput(): {
        [key: string]: string;
    } | undefined;
    private _tmpfs?;
    /**
     *
     */
    get tmpfs(): {
        [key: string]: string;
    };
    /**
     *
     */
    set tmpfs(value: {
        [key: string]: string;
    });
    /**
     *
     */
    resetTmpfs(): void;
    /**
     *
     */
    get tmpfsInput(): {
        [key: string]: string;
    } | undefined;
    private _user?;
    /**
     *
     */
    get user(): string;
    /**
     *
     */
    set user(value: string);
    /**
     *
     */
    resetUser(): void;
    /**
     *
     */
    get userInput(): string | undefined;
    private _usernsMode?;
    /**
     *
     */
    get usernsMode(): string;
    /**
     *
     */
    set usernsMode(value: string);
    /**
     *
     */
    resetUsernsMode(): void;
    /**
     *
     */
    get usernsModeInput(): string | undefined;
    private _workingDir?;
    /**
     *
     */
    get workingDir(): string;
    /**
     *
     */
    set workingDir(value: string);
    /**
     *
     */
    resetWorkingDir(): void;
    /**
     *
     */
    get workingDirInput(): string | undefined;
    private _capabilities?;
    /**
     *
     */
    get capabilities(): ContainerCapabilities[];
    /**
     *
     */
    set capabilities(value: ContainerCapabilities[]);
    /**
     *
     */
    resetCapabilities(): void;
    /**
     *
     */
    get capabilitiesInput(): ContainerCapabilities[] | undefined;
    private _devices?;
    /**
     *
     */
    get devices(): ContainerDevices[];
    /**
     *
     */
    set devices(value: ContainerDevices[]);
    /**
     *
     */
    resetDevices(): void;
    /**
     *
     */
    get devicesInput(): ContainerDevices[] | undefined;
    private _healthcheck?;
    /**
     *
     */
    get healthcheck(): ContainerHealthcheck[];
    /**
     *
     */
    set healthcheck(value: ContainerHealthcheck[]);
    /**
     *
     */
    resetHealthcheck(): void;
    /**
     *
     */
    get healthcheckInput(): ContainerHealthcheck[] | undefined;
    private _host?;
    /**
     *
     */
    get host(): ContainerHost[];
    /**
     *
     */
    set host(value: ContainerHost[]);
    /**
     *
     */
    resetHost(): void;
    /**
     *
     */
    get hostInput(): ContainerHost[] | undefined;
    private _labels?;
    /**
     *
     */
    get labels(): ContainerLabels[];
    /**
     *
     */
    set labels(value: ContainerLabels[]);
    /**
     *
     */
    resetLabels(): void;
    /**
     *
     */
    get labelsInput(): ContainerLabels[] | undefined;
    private _mounts?;
    /**
     *
     */
    get mounts(): ContainerMounts[];
    /**
     *
     */
    set mounts(value: ContainerMounts[]);
    /**
     *
     */
    resetMounts(): void;
    /**
     *
     */
    get mountsInput(): ContainerMounts[] | undefined;
    private _networksAdvanced?;
    /**
     *
     */
    get networksAdvanced(): ContainerNetworksAdvanced[];
    /**
     *
     */
    set networksAdvanced(value: ContainerNetworksAdvanced[]);
    /**
     *
     */
    resetNetworksAdvanced(): void;
    /**
     *
     */
    get networksAdvancedInput(): ContainerNetworksAdvanced[] | undefined;
    private _ports?;
    /**
     *
     */
    get ports(): ContainerPorts[];
    /**
     *
     */
    set ports(value: ContainerPorts[]);
    /**
     *
     */
    resetPorts(): void;
    /**
     *
     */
    get portsInput(): ContainerPorts[] | undefined;
    private _ulimit?;
    /**
     *
     */
    get ulimit(): ContainerUlimit[];
    /**
     *
     */
    set ulimit(value: ContainerUlimit[]);
    /**
     *
     */
    resetUlimit(): void;
    /**
     *
     */
    get ulimitInput(): ContainerUlimit[] | undefined;
    private _upload?;
    /**
     *
     */
    get upload(): ContainerUpload[];
    /**
     *
     */
    set upload(value: ContainerUpload[]);
    /**
     *
     */
    resetUpload(): void;
    /**
     *
     */
    get uploadInput(): ContainerUpload[] | undefined;
    private _volumes?;
    /**
     *
     */
    get volumes(): ContainerVolumes[];
    /**
     *
     */
    set volumes(value: ContainerVolumes[]);
    /**
     *
     */
    resetVolumes(): void;
    /**
     *
     */
    get volumesInput(): ContainerVolumes[] | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
